@@ -65,6 +65,8 @@ class Interface:  # pragma no cover
     The interface is used to connect a Model to the solver. To solve an ODE, as a minimum the methods
     get_deriv and get_states.
     """
+    def __init__(self, model: object):
+        self.model = model
 
     def get_deriv(self, t: float, y: np.array) -> Optional[np.ascontiguousarray]:
         """Function to return derivatives of state-space model. Must be implemented by user
@@ -340,18 +342,22 @@ class _JitHelper:
             if not self._is_reserved_nested_type(arg):
                 try:
                     _ = iter(arg)
-                    args__.append(self._add_args(arg, jit))
+                    if isinstance(arg, dict):
+                        if jit:
+                            raise TypeError(f"dicts are not as arguments allowed when jit=True {arg}")
+                        args__.append(self._add_kwargs(arg, jit))
+                    else:
+                        args__.append(self._add_args(arg, jit))
                 except TypeError as e:
                     if not "is not iterable" in e.__repr__():
                         raise
                     if isinstance(arg, _JitHelper):
                         args__.append(arg(jit=jit))
-                        #args__.append(arg.python_model)
                     else:
                         args__.append(arg)
             else:
                 args__.append(arg)
-        return args__
+        return tuple(args__)
 
     def _add_kwargs(self, kwargs_: dict, jit=False):
         kwargs__ = {}
@@ -359,13 +365,17 @@ class _JitHelper:
             if not self._is_reserved_nested_type(v):
                 try:
                     _ = iter(v)
-                    kwargs__.update({k: self._add_args(v, jit)})
+                    if isinstance(v, dict):
+                        if jit:
+                            raise TypeError(f"dicts are not as arguments allowed when jit=True {v}")
+                        kwargs__.update({k: self._add_kwargs(v, jit)})
+                    else:
+                        kwargs__.update({k: self._add_args(v, jit)})
                 except TypeError as e:
                     if not "is not iterable" in e.__repr__():
                         raise
                     if isinstance(v, _JitHelper):
                         kwargs__.update({k: v(jit=jit)})
-                        #kwargs__.update({k: v.python_model})
                     else:
                         kwargs__.update({k: v})
             else:
@@ -468,10 +478,11 @@ class Model:
 
     def __call__(self, *args, **kwargs):
         """When calling the Model object, the model is jitted. If the model is a component it returns the jitted class.
-        Creates a new class of type Model, the calls its init function.
+        Creates a new class of type Model, the calls its init function. Arguments such as lists are converted to tuples,
+        because numba prefers tuples
 
-        :param args: Arguments to the Model
-        :param kwargs: Keyword arguments to the Model
+        :param args: Arguments to the Model. If using numba, the arguments must be known types to numba
+        :param kwargs: Keyword arguments to the Model. If using numba, the arguments must be known types to numba
         :return: returns either a new instance of the Model class ifself, or a new instance of the jitted/non-jitted
         model_class
         :rtype: :class:`solver.interface.Model` | :class:`numba.core.registry.CPUDispatcher` | :class:object
